# CpaNlp: Accounting NLP toolkit
Redefining [Accounting](https://cpanlp.com/overview/redefine)!
Under construction! Not ready for use yet! Currently experimenting and planning!

Developed by Bfsu Intelligent Accounting Team (c) 2023

## Examples of How To Use (Buggy Alpha Version)

Creating A Server

```python
import cpanlp
# Other Code

# When You Are Done
```


Check out: https://cpanlp.com